@@ -1,3 +1,4 @@
+from datetime import datetime
 import pandas as pd
 import arrow
 
@@ -14,7 +15,7 @@ DEFAULT_LIMIT = "100"
 class ModelKey:
     """A model key. Represents a given point in time for the Transform configs."""
 
-    id: int
+    id: Optional[int]
     organization_id: int
     repository: str
     branch: str
@@ -30,7 +31,7 @@ class ModelKey:
     @classmethod
     def from_gql_dict(cls, _input: Dict[str, str]) -> "ModelKey":  # noqa: D
         return cls(
-            id=int(_input["id"]),
+            id=int(_input["id"]) if _input["id"] is not None else None,
             organization_id=int(_input["organizationId"]),
             repository=_input["gitRepo"],
             branch=_input["gitBranch"],
@@ -42,7 +43,7 @@ class ModelKey:
     @classmethod
     def from_snake_dict(cls, _input: Dict[str, str]) -> "ModelKey":  # noqa: D
         return cls(
-            id=int(_input["id"]),
+            id=int(_input["id"]) if _input["id"] is not None else None,
             organization_id=int(_input["organization_id"]),
             repository=_input["repository"],
             branch=_input["branch"],
@@ -160,6 +161,7 @@ class MetricType(Enum):
     RATIO = "ratio"
     EXPR = "expr"
     CUMULATIVE = "cumulative"
+    DERIVED = "derived"
 
 
 @dataclass
@@ -273,6 +275,13 @@ class MqlQueryResultSource(Enum):
     MATERIALIZED_QUERY_CACHE = "MATERIALIZED_QUERY_CACHE"
 
 
+class QueryJobType(Enum):
+    """Type of query job."""
+
+    DIM_VAL = "DIM_VAL"
+    DW_VALIDATION = "DW_VALIDATION"
+
+
 @dataclass(frozen=True)
 class MqlQueryResultSeries:  # noqa: D
     value: float
@@ -500,3 +509,34 @@ class Query:
             dimensions=_input["dimensions"],
             status=MqlQueryStatus(_input["status"]),
         )
+
+
+@dataclass(frozen=True)
+class QueryJobStatusResp:  # noqa: D
+    query_id: str
+    status: MqlQueryStatus
+    startTime: Optional[datetime]
+    endTime: Optional[datetime]
+    queryRuntime: float
+    queryType: QueryJobType
+    error: Optional[str]
+
+    @property
+    def is_complete(self) -> bool:
+        """These statuses indicate the Query has completed execution"""
+        return self.status in [
+            None,
+            MqlQueryStatus.SUCCESSFUL,
+            MqlQueryStatus.FAILED,
+            MqlQueryStatus.UNHANDLED_EXCEPTION,
+        ]
+
+    @property
+    def is_successful(self) -> bool:
+        """Indicate whether the Query has completed successfully"""
+        return self.status == MqlQueryStatus.SUCCESSFUL
+
+    @property
+    def is_failed(self) -> bool:
+        """Indicate whether the Query has completed successfully"""
+        return self.status in [MqlQueryStatus.FAILED, MqlQueryStatus.UNHANDLED_EXCEPTION]
