@@ -2,6 +2,7 @@ import pandas as pd
 import requests
 
 from typing import Dict, List, Optional, Tuple
+from metricflow.model.validations.validator_helpers import ModelValidationResults
 
 from .auth import TransformAuth
 from .models import (
@@ -23,7 +24,7 @@ from .models import (
     TimeGranularity,
     UserState,
 )
-from .interfaces import DWValidationType, MQLInterface
+from .interfaces import AsyncDWValidationType, DWValidationType, MQLInterface
 from .exceptions import QueryRuntimeException
 
 
@@ -81,6 +82,14 @@ class MQLClient:
         )
         return self.context.mql_client.get_query_status(query_id)
 
+    def create_data_warehouse_validations_job(
+        self, dw_validation_type: AsyncDWValidationType, model_key_id: Optional[int] = None
+    ) -> str:
+        """Submits a data warehouse validations job and return the associated query job id"""
+        return self.context.mql_client.create_data_warehouse_validations_job(
+            dw_validation_type=dw_validation_type, model_id=model_key_id
+        )
+
     def query_latest_metric_change(self, metric_name: str) -> MqlQueryStatusResp:
         """Create a query for the latest change in the specified metric"""
         query_id = self.context.mql_client.query_latest_metric_change(metric_name)
@@ -268,13 +277,34 @@ class MQLClient:
         model_key = self.get_model_key(model_key_id) if model_key_id else None
         return sorted(self.context.mql_client.get_materializations(model_key), key=lambda m: m.name)
 
-    def commit_configs(self, config_dir: str, is_validation: bool = False) -> ModelKey:
+    def commit_configs(
+        self,
+        config_dir: str,
+        is_validation: bool = False,
+        is_dbt_model: bool = False,
+        dbt_profile: Optional[str] = None,
+        dbt_target: Optional[str] = None,
+    ) -> Tuple[ModelKey, ModelValidationResults]:
         """Validates and commits yaml transform configs in the provided directory. Returns a ModelKey object."""
-        return self.context.backend_client.commit_configs(config_dir=config_dir, is_validation=is_validation)
+        return self.context.backend_client.commit_configs(
+            config_dir=config_dir,
+            is_validation=is_validation,
+            is_dbt_model=is_dbt_model,
+            dbt_profile=dbt_profile,
+            dbt_target=dbt_target,
+        )
 
-    def validate_configs(self, config_dir: str) -> ModelKey:
+    def validate_configs(
+        self,
+        config_dir: str,
+        is_dbt_model: bool = False,
+        dbt_profile: Optional[str] = None,
+        dbt_target: Optional[str] = None,
+    ) -> Tuple[ModelKey, ModelValidationResults]:
         """Finds and validates yaml transform configs in the provided directory. Returns a tuple (repo, branch, commit)"""
-        return self.context.backend_client.validate_configs(config_dir)
+        return self.context.backend_client.validate_configs(
+            config_dir=config_dir, is_dbt_model=is_dbt_model, dbt_profile=dbt_profile, dbt_target=dbt_target
+        )
 
     def promote_model(self, model_key: ModelKey) -> None:
         """Promotes a given model key to be the current/primary model for the organization"""
@@ -343,6 +373,17 @@ class MQLClient:
         """
         return self.context.mql_client.get_query_dataframe(query_id, timeout)
 
+    def get_data_warehouse_validations_job_result(
+        self, query_id: str, timeout: Optional[int] = None
+    ) -> ModelValidationResults:
+        """Retrieves query results in Pandas DataFrame format.
+
+        Includes logic for:
+        1. Polling for completion
+        2. Converting JSON to a ModelValidationResults
+        """
+        return self.context.mql_client.get_data_warehouse_validation_query(query_id, timeout)
+
     def get_model_key(self, model_key_id: int) -> ModelKey:
         """Retrieves ModelKey object given the id."""
         return self.context.backend_client.get_model_key(model_key_id)
@@ -379,11 +420,15 @@ class MQLClient:
         dimensions = self.context.mql_client.get_dimensions(metric_names, model_key)
         return {dim.name: dim for dim in dimensions}
 
-    def get_data_warehouse_issues(self, type: DWValidationType, model_key_id: Optional[int] = None) -> List[str]:
-        """Retrieves a list of warehosue validation issues with for the type on the model."""
+    def get_data_warehouse_issues(
+        self, type: DWValidationType, model_key_id: Optional[int] = None
+    ) -> ModelValidationResults:
+        """DEPRECATED: Use create_data_warehouse_validations_job + get_data_warehouse_validations_job_result instead
+
+        Retrieves a list of warehosue validation issues with for the type on the model.
+        """
         model_key = self.get_model_key(model_key_id) if model_key_id else None
-        issues = self.context.mql_client.get_data_warehouse_validation_issues(type, model_key)
-        return issues
+        return self.context.mql_client.get_data_warehouse_validation_issues(type, model_key)
 
     def get_query_status(self, query_id: str) -> MqlQueryStatusResp:
         """Returns a query response object."""
